@@ -73,7 +73,13 @@ class TestPKConstants(TestCase):
         self.assertEqual(PassKit.PKPaymentButtonTypeSupport, 13)
         self.assertEqual(PassKit.PKPaymentButtonTypeContribute, 14)
         self.assertEqual(PassKit.PKPaymentButtonTypeTip, 15)
+        self.assertEqual(PassKit.PKPaymentButtonTypeContinue, 16)
 
     @min_os_level("11.5")
     def test_constants11_5(self):
         self.assertIsInstance(PassKit.PKPaymentNetworkMir, str)
+
+    @min_os_level("12.0")
+    def test_constants12_0(self):
+        self.assertIsInstance(PassKit.PKPaymentNetworkWaon, str)
+        self.assertIsInstance(PassKit.PKPaymentNetworkNanaco, str)
